pub trait TransParamLookup {
// Required methods
fn get_dms(&self, key: &str) -> Option<f64>;
fn get_f64(&self, key: &str) -> Option<f64>;
fn get_int(&self, key: &str) -> Option<i64>;
fn get_str(&self, key: &str) -> Option<&str>;
fn get_bool(&self, key: &str) -> bool;
fn exists(&self, key: &str) -> bool;
}Expand description
A trait the engine implements to give a transformation access to its specific params.
Mirrors oxiproj_projections::ProjParamLookup.
Required Methods
Sourcefn get_dms(&self, key: &str) -> Option<f64>
fn get_dms(&self, key: &str) -> Option<f64>
Look up a key whose value is an angle, returning radians (parsed via PROJ dmstor).
Sourcefn get_f64(&self, key: &str) -> Option<f64>
fn get_f64(&self, key: &str) -> Option<f64>
Look up a key whose value is a plain floating-point number.
Dyn Compatibility
This trait is dyn compatible.
In older versions of Rust, dyn compatibility was called "object safety".